@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    factory.h -- plugin factory header file. */
@@ -18,8 +18,7 @@ extern reiser4_plug_t *reiser4_factory_nfind(char *name);
 extern errno_t reiser4_factory_foreach(plug_func_t plug_func,
 				       void *data);
 
-extern errno_t reiser4_factory_unload(reiser4_plug_t *plug);
-extern reiser4_plug_t * reiser4_factory_load(plug_class_t *class);
+extern void reiser4_factory_load(reiser4_plug_t *plug);
 
 extern reiser4_plug_t *reiser4_factory_ifind(rid_t type, rid_t id);
 
