@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    item.h -- common item functions. */
@@ -24,7 +24,7 @@ extern errno_t reiser4_item_maxreal_key(reiser4_place_t *place,
 extern errno_t reiser4_item_update_link(reiser4_place_t *place,
 					blk_t blk);
 
-extern uint16_t reiser4_item_overhead(reiser4_plug_t *plug);
+extern uint16_t reiser4_item_overhead(reiser4_item_plug_t *plug);
 
 extern void reiser4_item_set_flag(reiser4_place_t *place, 
 				  uint16_t flag);
@@ -48,7 +48,7 @@ extern lookup_t reiser4_item_collision(reiser4_place_t *place,
 
 extern uint32_t reiser4_item_units(reiser4_place_t *place);
 extern blk_t reiser4_item_down_link(reiser4_place_t *place);
-extern bool_t reiser4_item_branch(reiser4_plug_t *plug);
+extern bool_t reiser4_item_branch(reiser4_item_plug_t *plug);
 
 extern errno_t reiser4_item_get_key(reiser4_place_t *place,
 				    reiser4_key_t *key);
