@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    key.h -- reiser4 key defines and functions. */
@@ -8,6 +8,8 @@
 
 #include <reiser4/types.h>
 
+extern int reiser4_key_compshort(reiser4_key_t *key1,
+				 reiser4_key_t *key2);
 #ifndef ENABLE_MINIMAL
 extern void reiser4_key_free(reiser4_key_t *key);
 
@@ -24,9 +26,6 @@ extern oid_t reiser4_key_get_objectid(reiser4_key_t *key);
 extern oid_t reiser4_key_get_locality(reiser4_key_t *key);
 extern uint64_t reiser4_key_get_ordering(reiser4_key_t *key);
 
-extern int reiser4_key_compshort(reiser4_key_t *key1,
-				 reiser4_key_t *key2);
-
 extern errno_t reiser4_key_set_type(reiser4_key_t *key,
 				    uint32_t type);
 
@@ -47,8 +46,8 @@ extern errno_t reiser4_key_build_generic(reiser4_key_t *key,
 					 uint64_t offset);
 
 extern void reiser4_key_build_hashed(reiser4_key_t *key,
-				     reiser4_plug_t *hash,
-				     reiser4_plug_t *fibre,
+				     reiser4_hash_plug_t *hash,
+				     reiser4_fibre_plug_t *fibre,
 				     oid_t locality,
 				     oid_t objectid,
 				     char *name);
