@@ -1,4 +1,4 @@
-/* Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    repair/semantic.h -- the structures and methods needed for semantic
@@ -14,10 +14,14 @@
 
 /* Statistics gathered during the pass. */
 typedef struct repair_semantic_stat {
-	uint64_t dirs, files, syms, spcls;
-	uint64_t ldirs, lfiles, lsyms, lspcls;
+	uint64_t reached_files;
+	uint64_t lost_files;
 	uint64_t shared, rm_entries, broken;
 	uint64_t oid;
+
+	/* Files counted on previous passes. */
+	uint64_t statdatas;
+	uint64_t files;
 	time_t time;
 } repair_semantic_stat_t;
 
@@ -33,9 +37,9 @@ typedef struct repair_semantic {
 	reiser4_object_t *root;
 	reiser4_object_t *lost;
 	
-	repair_progress_handler_t *progress_handler;
-	repair_progress_t *progress;
 	repair_semantic_stat_t stat;
+
+	aal_gauge_t *gauge;
 } repair_semantic_t;
 
 extern errno_t repair_semantic(repair_semantic_t *sem);
