@@ -1,4 +1,4 @@
-/* Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by 
+/* Copyright 2001-2005 by Hans Reiser, licensing governed by 
    reiser4progs/COPYING.
    
    librepair/item.c -- common repair item functions. */
@@ -32,14 +32,13 @@ errno_t repair_item_check_struct(reiser4_place_t *place, uint8_t mode) {
 	aal_assert("vpf-791", place != NULL);
 	aal_assert("vpf-792", place->node != NULL);
 	
-	if (!place->plug->o.item_ops->repair->check_struct)
+	if (!place->plug->repair->check_struct)
 		return 0;
 	
 	aal_memset(&hint, 0, sizeof(hint));
 	hint.mode = mode;
 	
-	if ((res = plug_call(place->plug->o.item_ops->repair,
-			     check_struct, place, &hint)))
+	if ((res = objcall(place, repair->check_struct, &hint)))
 		return res;
 	
 	if (!hint.len)
@@ -60,14 +59,14 @@ errno_t repair_item_check_layout(reiser4_place_t *place, region_func_t func,
 	aal_assert("vpf-793", place != NULL);
 	aal_assert("vpf-794", place->node != NULL);
 	
-	if (!place->plug->o.item_ops->repair->check_layout)
+	if (!place->plug->repair->check_layout)
 		return 0;
 	
 	aal_memset(&hint, 0, sizeof(hint));
 	hint.mode = mode;
 	
-	if ((res = plug_call(place->plug->o.item_ops->repair, check_layout, 
-			     place, &hint, func, data)) < 0)
+	res = place->plug->repair->check_layout(place, &hint, func, data);
+	if (res < 0)
 		return res;
 	
 	if (!hint.len)
@@ -82,10 +81,9 @@ void repair_item_print(reiser4_place_t *place, aal_stream_t *stream) {
 	aal_assert("umka-1550", stream != NULL);
 	aal_assert("umka-1449", place->plug != NULL);
 
-	if (!place->plug->o.item_ops->debug->print)
+	if (!place->plug->debug->print)
 		return;
 	
-	plug_call(place->plug->o.item_ops->debug, print,
-		  place, stream, 0);
+	place->plug->debug->print(place, stream, 0);
 }
 
