@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    nodeptr40.h -- reiser4 nodeptr item structures. */
@@ -9,12 +9,11 @@
 #include <aal/libaal.h>
 #include <reiser4/plugin.h>
 
-struct nodeptr40 {
-	d64_t ptr;
-};
-
 extern reiser4_core_t *nodeptr40_core;
-typedef struct nodeptr40 nodeptr40_t;
+
+typedef struct nodeptr40 {
+	d64_t ptr;
+} nodeptr40_t;
 
 #define nodeptr40_body(place) ((nodeptr40_t *)place->body)
 
