@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    oid40_repair.c -- reiser4 oid allocator plugin. */
@@ -8,51 +8,49 @@
 #include "oid40.h"
 #include "oid40_repair.h"
 
-extern reiser4_plug_t oid40_plug;
-
-static uint32_t oid40_get_state(generic_entity_t *entity) {
+static uint32_t oid40_get_state(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-2088", entity != NULL);
-	return ((oid40_t *)entity)->state;
+	return PLUG_ENT(entity)->state;
 }
 
 /* Returnes next oid to be used */
 
-static uint64_t oid40_get_next_oid(generic_entity_t *entity) {
+static uint64_t oid40_get_next_oid(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-1109", entity != NULL);
-	return ((oid40_t *)entity)->next;
+	return PLUG_ENT(entity)->next;
 }
 
 /* Returns number of used oids */
-static uint64_t oid40_get_used_oid(generic_entity_t *entity) {
+static uint64_t oid40_get_used_oid(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-530", entity != NULL);
-	return ((oid40_t *)entity)->used;
+	return PLUG_ENT(entity)->used;
 }
 
-static void oid40_set_state(generic_entity_t *entity,
+static void oid40_set_state(reiser4_oid_ent_t *entity,
 			    uint32_t state)
 {
 	aal_assert("umka-2089", entity != NULL);
-	((oid40_t *)entity)->state = state;
+	PLUG_ENT(entity)->state = state;
 }
 
 /* Updates next oid to be used */
 
-static void oid40_set_next_oid(generic_entity_t *entity, uint64_t next) {
+static void oid40_set_next_oid(reiser4_oid_ent_t *entity, uint64_t next) {
 	aal_assert("vpf-1588", entity != NULL);
-	((oid40_t *)entity)->next = next;
-	((oid40_t *)entity)->state = (1 << ENTITY_DIRTY);
+	PLUG_ENT(entity)->next = next;
+	PLUG_ENT(entity)->state = (1 << ENTITY_DIRTY);
 }
 
 /* Updates number of used oids */
-static void oid40_set_used_oid(generic_entity_t *entity, uint64_t used) {
+static void oid40_set_used_oid(reiser4_oid_ent_t *entity, uint64_t used) {
 	aal_assert("umka-530", entity != NULL);
-	((oid40_t *)entity)->used = used;
-	((oid40_t *)entity)->state = (1 << ENTITY_DIRTY);
+	PLUG_ENT(entity)->used = used;
+	PLUG_ENT(entity)->state = (1 << ENTITY_DIRTY);
 }
 
 
 /* Open oid allocator on passed format instance. */
-static generic_entity_t *oid40_open(generic_entity_t *format) {
+static reiser4_oid_ent_t *oid40_open(reiser4_format_ent_t *format) {
 	oid40_t *oid;
 
 	aal_assert("umka-2664", format != NULL);
@@ -65,22 +63,21 @@ static generic_entity_t *oid40_open(generic_entity_t *format) {
 	oid->plug = &oid40_plug;
 
 	/* Getting oid pluign work area from format plugin. */
-	plug_call(format->plug->o.format_ops, oid_area,
-		  format, &oid->start, &oid->len);
+	entcall(format, oid_area, &oid->start, &oid->len);
     
 	oid->next = oid40_get_next(oid->start);
 	oid->used = oid40_get_used(oid->start);
 	
-	return (generic_entity_t *)oid;
+	return (reiser4_oid_ent_t *)oid;
 }
 
-static void oid40_close(generic_entity_t *entity) {
+static void oid40_close(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-510", entity != NULL);
 	aal_free(entity);
 }
 
 /* Initializes oid allocator instance and returns it to caller. */
-static generic_entity_t *oid40_create(generic_entity_t *format) {
+static reiser4_oid_ent_t *oid40_create(reiser4_format_ent_t *format) {
 	oid40_t *oid;
 
 	if (!(oid = aal_calloc(sizeof(*oid), 0)))
@@ -96,73 +93,68 @@ static generic_entity_t *oid40_create(generic_entity_t *format) {
 	oid->next = OID40_RESERVED;
 
 	/* Getting oid pluign work area from format plugin. */
-	plug_call(format->plug->o.format_ops, oid_area,
-		  format, &oid->start, &oid->len);
+	entcall(format, oid_area, &oid->start, &oid->len);
 	
 	oid40_set_next(oid->start, oid->next);
 	oid40_set_used(oid->start, oid->used);
 
-	return (generic_entity_t *)oid;
+	return (reiser4_oid_ent_t *)oid;
 }
 
 /* Updating next and used values in oid allocator dedicated area */
-static errno_t oid40_sync(generic_entity_t *entity) {
-	generic_entity_t *format;
+static errno_t oid40_sync(reiser4_oid_ent_t *entity) {
+	reiser4_format_ent_t *format;
 	uint32_t state;
 	
 	aal_assert("umka-1016", entity != NULL);
 
-	oid40_set_next(((oid40_t *)entity)->start, 
-		       ((oid40_t *)entity)->next);
+	oid40_set_next(PLUG_ENT(entity)->start, 
+		       PLUG_ENT(entity)->next);
     
-	oid40_set_used(((oid40_t *)entity)->start, 
-		       ((oid40_t *)entity)->used);
+	oid40_set_used(PLUG_ENT(entity)->start, 
+		       PLUG_ENT(entity)->used);
 
 	/* Mark the format dirty. */
-	format = ((oid40_t *)entity)->format;
-	
-	state = plug_call(format->plug->o.format_ops,
-			  get_state, format);
-	
-	plug_call(format->plug->o.format_ops, set_state, 
-		  format, state | (1 << ENTITY_DIRTY));
+	format = PLUG_ENT(entity)->format;
+	state = entcall(format, get_state);
+	entcall(format, set_state, state | (1 << ENTITY_DIRTY));
 	
 	return 0;
 }
 
 /* Returns free oid and marks it as used */
-static oid_t oid40_allocate(generic_entity_t *entity) {
+static oid_t oid40_allocate(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-513", entity != NULL);
 
-	((oid40_t *)entity)->next++;
-	((oid40_t *)entity)->used++;
+	PLUG_ENT(entity)->next++;
+	PLUG_ENT(entity)->used++;
 
-	((oid40_t *)entity)->state |= (1 << ENTITY_DIRTY);
-	return ((oid40_t *)entity)->next - 1;
+	PLUG_ENT(entity)->state |= (1 << ENTITY_DIRTY);
+	return PLUG_ENT(entity)->next - 1;
 }
 
 /* Releases passed oid */
-static void oid40_release(generic_entity_t *entity, 
+static void oid40_release(reiser4_oid_ent_t *entity, 
 			  oid_t oid)
 {
 	aal_assert("umka-528", entity != NULL);
 
-	((oid40_t *)entity)->used--;
-	((oid40_t *)entity)->state |= (1 << ENTITY_DIRTY);
+	PLUG_ENT(entity)->used--;
+	PLUG_ENT(entity)->state |= (1 << ENTITY_DIRTY);
 }
 
 /* Returns number of free oids */
-static oid_t oid40_free(generic_entity_t *entity) {
+static oid_t oid40_free(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-961", entity != NULL);
-	return MAX_UINT64 - ((oid40_t *)entity)->next;
+	return MAX_UINT64 - PLUG_ENT(entity)->next;
 }
 
 /* Checks oid allocator for validness */
-static errno_t oid40_valid(generic_entity_t *entity) {
+static errno_t oid40_valid(reiser4_oid_ent_t *entity) {
 	aal_assert("umka-966", entity != NULL);
 
 	/* Next oid should not be less than the root locality */
-	if (((oid40_t *)entity)->next < OID40_ROOT_LOCALITY)
+	if (PLUG_ENT(entity)->next < OID40_ROOT_LOCALITY)
 		return -EINVAL;
 
 	return 0;
@@ -178,7 +170,13 @@ static oid_t oid40_root_objectid() {
 	return OID40_ROOT_OBJECTID;
 }
 
-reiser4_oid_ops_t oid40_ops = {
+reiser4_oid_plug_t oid40_plug = {
+	.p = {
+		.id    = {OID_REISER40_ID, 0, OID_PLUG_TYPE},
+		.label = "oid40",
+		.desc  = "Inode number allocator plugin.",
+	},
+	
 	.open		= oid40_open,
 	.close		= oid40_close,
 	.create		= oid40_create,
@@ -203,19 +201,4 @@ reiser4_oid_ops_t oid40_ops = {
 	.slink_locality = oid40_slink_locality
 };
 
-reiser4_plug_t oid40_plug = {
-	.cl    = class_init,
-	.id    = {OID_REISER40_ID, 0, OID_PLUG_TYPE},
-	.label = "oid40",
-	.desc  = "Inode allocator for reiser4. ",
-	.o = {
-		.oid_ops = &oid40_ops
-	}
-};
-
-static reiser4_plug_t *oid40_start(reiser4_core_t *c) {
-	return &oid40_plug;
-}
-
-plug_register(oid40, oid40_start, NULL);
 #endif
