@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    oid40.h -- reiser4 default oid allocator structures. */
@@ -16,9 +16,9 @@
 
 #define OID40_LOST_OBJECTID	(OID40_RESERVED - 1)
 
-struct oid40 {
-	reiser4_plug_t *plug;
-	generic_entity_t *format;
+typedef struct oid40 {
+	reiser4_oid_plug_t *plug;
+	reiser4_format_ent_t *format;
 
 	void *start;
 	uint32_t len;
@@ -26,9 +26,11 @@ struct oid40 {
 	uint64_t next;
 	uint64_t used;
 	uint32_t state;
-};
+} oid40_t;
 
-typedef struct oid40 oid40_t;
+extern reiser4_oid_plug_t oid40_plug;
+
+#define PLUG_ENT(p) ((oid40_t *)p)
 
 #define oid40_get_next(area)            LE64_TO_CPU(*((d64_t *)area))
 #define oid40_set_next(area, val)       (*((d64_t *)area) = CPU_TO_LE64(val))
